/* VzImagination (C) 2018-2019 Stephane Charette <stephanecharette@gmail.com>
 * $Id: TestCompare.cpp 2741 2019-04-09 17:04:20Z stephane $
 */

#include "TestUtil.hpp"


TEST(Compare, EmptyImagesMatch)
{
	vz::Imagination img1;
	vz::Imagination img2;

	ASSERT_TRUE(img1.empty());
	ASSERT_TRUE(img2.empty());
	ASSERT_EQ(img1, img2);

	img1.clear();

	ASSERT_TRUE(img1.empty());
	ASSERT_TRUE(img2.empty());
	ASSERT_EQ(img1, img2);
}


TEST(Compare, UniqueImages)
{
	// the test images should all be different
	test_images();

	std::vector<vz::Imagination> v;

	for (const auto & [path, name] : trivial_test_images())
	{
		std::cout << "comparing " << name << " against " << v.size() << " other loaded images" << std::endl;

		vz::Imagination img(path);
		ASSERT_FALSE(img.empty());
		ASSERT_EQ(img.size(), 1);

		for (vz::Imagination & rhs : v)
		{
			ASSERT_NE(img, rhs);
		}

		v.push_back(img);
	}
}


TEST(Compare, ClearImages)
{
	test_images();

	vz::Imagination img1("w.jpg");
	vz::Imagination img2("y.jpg");

	ASSERT_FALSE(img1.empty());
	ASSERT_FALSE(img2.empty());
	ASSERT_NE(img1, img2);

	img1.clear();
	img2.clear();

	ASSERT_TRUE(img1.empty());
	ASSERT_TRUE(img2.empty());
	ASSERT_EQ(img1, img2);
}


TEST(Compare, SetEmptyImages)
{
	test_images();

	vz::Imagination img1("y.jpg");
	vz::Imagination img2("g.jpg");

	ASSERT_FALSE(img1.empty());
	ASSERT_FALSE(img2.empty());
	ASSERT_NE(img1, img2);

	img1.clear();

	cv::Mat mat;
	img2.set_original(mat);

	ASSERT_TRUE(img1.empty());
	ASSERT_TRUE(img2.empty());
	ASSERT_EQ(img1, img2);
}
